@@ -1,4 +1,4 @@
-/*      $Id: display.h,v 1.15 2004/12/09 22:44:20 olivier Exp $
+/*      $Id: display.h,v 1.16 2004/12/15 19:16:55 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -77,51 +77,51 @@
 #define NET_STARTUP_ID                                          17
 #define NET_SUPPORTED                                           18
 #define NET_SUPPORTING_WM_CHECK                                 19
-#define NET_SYSTEM_TRAY_MANAGER                                 20
-#define NET_SYSTEM_TRAY_OPCODE                                  21
-#define NET_WM_ACTION_CHANGE_DESKTOP                            22
-#define NET_WM_ACTION_CLOSE                                     23
-#define NET_WM_ACTION_MAXIMIZE_HORZ                             24
-#define NET_WM_ACTION_MAXIMIZE_VERT                             25
-#define NET_WM_ACTION_MOVE                                      26
-#define NET_WM_ACTION_RESIZE                                    27
-#define NET_WM_ACTION_SHADE                                     28
-#define NET_WM_ACTION_STICK                                     29
-#define NET_WM_ALLOWED_ACTIONS                                  30
-#define NET_WM_CONTEXT_HELP                                     31
-#define NET_WM_DESKTOP                                          32
-#define NET_WM_ICON                                             33
-#define NET_WM_ICON_GEOMETRY                                    34
-#define NET_WM_ICON_NAME                                        35
-#define NET_WM_MOVERESIZE                                       36
-#define NET_WM_NAME                                             37
-#define NET_WM_WINDOW_OPACITY                                   38
-#define NET_WM_STATE                                            39
-#define NET_WM_STATE_ABOVE                                      40
-#define NET_WM_STATE_BELOW                                      41
-#define NET_WM_STATE_DEMANDS_ATTENTION                          42
-#define NET_WM_STATE_FULLSCREEN                                 43
-#define NET_WM_STATE_HIDDEN                                     44
-#define NET_WM_STATE_MAXIMIZED_HORZ                             45
-#define NET_WM_STATE_MAXIMIZED_VERT                             46
-#define NET_WM_STATE_MODAL                                      47
-#define NET_WM_STATE_SHADED                                     48
-#define NET_WM_STATE_SKIP_PAGER                                 49
-#define NET_WM_STATE_SKIP_TASKBAR                               50
-#define NET_WM_STATE_STICKY                                     51
-#define NET_WM_STRUT                                            52
-#define NET_WM_STRUT_PARTIAL                                    53
-#define NET_WM_USER_TIME                                        54
-#define NET_WM_WINDOW_TYPE                                      55
-#define NET_WM_WINDOW_TYPE_DESKTOP                              56
-#define NET_WM_WINDOW_TYPE_DIALOG                               57
-#define NET_WM_WINDOW_TYPE_DOCK                                 58
-#define NET_WM_WINDOW_TYPE_MENU                                 59
-#define NET_WM_WINDOW_TYPE_NORMAL                               60
-#define NET_WM_WINDOW_TYPE_SPLASH                               61
-#define NET_WM_WINDOW_TYPE_TOOLBAR                              62
-#define NET_WM_WINDOW_TYPE_UTILITY                              63
-#define NET_WORKAREA                                            64
+#define NET_SYSTEM_TRAY_OPCODE                                  20
+#define NET_WM_ACTION_CHANGE_DESKTOP                            21
+#define NET_WM_ACTION_CLOSE                                     22
+#define NET_WM_ACTION_MAXIMIZE_HORZ                             23
+#define NET_WM_ACTION_MAXIMIZE_VERT                             24
+#define NET_WM_ACTION_MOVE                                      25
+#define NET_WM_ACTION_RESIZE                                    26
+#define NET_WM_ACTION_SHADE                                     27
+#define NET_WM_ACTION_STICK                                     28
+#define NET_WM_ALLOWED_ACTIONS                                  29
+#define NET_WM_CONTEXT_HELP                                     30
+#define NET_WM_DESKTOP                                          31
+#define NET_WM_ICON                                             32
+#define NET_WM_ICON_GEOMETRY                                    33
+#define NET_WM_ICON_NAME                                        34
+#define NET_WM_MOVERESIZE                                       35
+#define NET_WM_NAME                                             36
+#define NET_WM_WINDOW_OPACITY                                   37
+#define NET_WM_STATE                                            38
+#define NET_WM_STATE_ABOVE                                      39
+#define NET_WM_STATE_BELOW                                      40
+#define NET_WM_STATE_DEMANDS_ATTENTION                          41
+#define NET_WM_STATE_FULLSCREEN                                 42
+#define NET_WM_STATE_HIDDEN                                     43
+#define NET_WM_STATE_MAXIMIZED_HORZ                             44
+#define NET_WM_STATE_MAXIMIZED_VERT                             45
+#define NET_WM_STATE_MODAL                                      46
+#define NET_WM_STATE_SHADED                                     47
+#define NET_WM_STATE_SKIP_PAGER                                 48
+#define NET_WM_STATE_SKIP_TASKBAR                               49
+#define NET_WM_STATE_STICKY                                     50
+#define NET_WM_STRUT                                            51
+#define NET_WM_STRUT_PARTIAL                                    52
+#define NET_WM_USER_TIME                                        53
+#define NET_WM_WINDOW_TYPE                                      54
+#define NET_WM_WINDOW_TYPE_DESKTOP                              55
+#define NET_WM_WINDOW_TYPE_DIALOG                               56
+#define NET_WM_WINDOW_TYPE_DOCK                                 57
+#define NET_WM_WINDOW_TYPE_MENU                                 58
+#define NET_WM_WINDOW_TYPE_NORMAL                               59
+#define NET_WM_WINDOW_TYPE_SPLASH                               60
+#define NET_WM_WINDOW_TYPE_TOOLBAR                              61
+#define NET_WM_WINDOW_TYPE_UTILITY                              62
+#define NET_WORKAREA                                            63
+#define MANAGER                                                 64
 #define PIXMAP                                                  65
 #define SM_CLIENT_ID                                            66
 #define UTF8_STRING                                             67
